@@ -6,13 +6,15 @@ Provides a terminal interface similar to cursor-agent
 
 import argparse
 import asyncio
+import json
 import os
 import random
 import sys
 import time
+import hashlib
 from datetime import datetime
 from pathlib import Path
-from typing import Optional
+from typing import Optional, Dict
 
 from rich import box
 from rich.console import Console
@@ -28,6 +30,26 @@ from .cli_workflow import WorkflowCLI
 from .workflow import WorkflowManager, Paper, parse_paper_from_response
 from .session_manager import SessionManager
 
+PRESET_SCENARIOS: Dict[str, Dict[str, str]] = {
+    "Research sprint": {
+        "prompt": "Run a literature review on retrieval-augmented generation, summarise three key papers and cite sources.",
+        "highlight": "Archive API + guardrails"
+    },
+    "Data audit": {
+        "prompt": "Inspect sales_data.csv, perform exploratory stats, and flag any anomalies worth investigating.",
+        "highlight": "Shell analytics + guardrails"
+    },
+    "Financial briefing": {
+        "prompt": "Compare NVDA and AMD revenue and margin trends for the last 4 quarters using FinSight.",
+        "highlight": "FinSight multi-ticker"
+    },
+    "Team handoff": {
+        "prompt": "Summarise our last session and note any follow-up tasks saved in the archive for project alpha.",
+        "highlight": "Archive memory"
+    },
+}
+
+
 class NocturnalCLI:
     """Command Line Interface for Cite Agent"""
     
@@ -53,6 +75,18 @@ class NocturnalCLI:
             "Remember the sandbox: prefix shell commands with [bold]![/] to execute safe utilities only.",
             "If you see an auto-update notice, the CLI will restart itself to load the latest build.",
         ]
+        self._default_artifacts = Path("artifacts_autonomy.json")
+
+    def _record_session_event(self, success: bool) -> None:
+        try:
+            manager = TelemetryManager.get()
+            email = os.getenv("NOCTURNAL_ACCOUNT_EMAIL", "")
+            payload = {"success": bool(success)}
+            if email:
+                payload["user"] = hashlib.sha256(email.encode("utf-8")).hexdigest()[:16]
+            manager.record("session_login", payload)
+        except Exception:
+            pass
     
     def handle_user_friendly_session(self):
         """Handle session management with user-friendly interface"""
@@ -78,7 +112,9 @@ class NocturnalCLI:
         # Handle user-friendly session management (skip prompts in non-interactive mode)
         if not non_interactive:
             if not self.handle_user_friendly_session():
+                self._record_session_event(False)
                 return False
+            self._record_session_event(True)
         
         self._show_intro_panel()
 
@@ -189,13 +225,100 @@ class NocturnalCLI:
     def _show_ready_panel(self):
         panel = Panel(
             "Systems check complete.\n"
-            "Type [bold]help[/] for commands or [bold]tips[/] for power moves.",
+            "Type [bold]help[/] for commands or [bold]tips[/] for power moves.\n"
+            "[dim]Press Ctrl+C while the agent is thinking to interrupt and ask something else.[/dim]",
             title="✅ Cite Agent ready!",
             border_style="green",
             padding=(1, 2),
             box=box.ROUNDED,
         )
         self.console.print(panel)
+
+    def show_presets(self) -> None:
+        table = Table(title="🚀 Beta Showcase Presets", box=box.ROUNDED, show_edge=True)
+        table.add_column("Scenario", style="bold cyan")
+        table.add_column("Prompt", style="white")
+        table.add_column("Highlights", style="magenta")
+        for name, payload in PRESET_SCENARIOS.items():
+            table.add_row(name, payload["prompt"], payload["highlight"])
+        self.console.print(table)
+        self.console.print("[dim]Tip: run [/dim][bold]nocturnal \"<prompt>\"[/bold][dim] to execute a preset immediately.[/dim]")
+
+    def show_metrics(self, artifacts: Optional[Path] = None) -> None:
+        artifacts_path = artifacts or self._default_artifacts
+        if not artifacts_path.exists():
+            self.console.print(
+                "[warning]No metrics file found.[/warning] Run [bold]python3 scripts/run_beta_showcase.py[/bold] first."
+            )
+            return
+
+        try:
+            payload = json.loads(artifacts_path.read_text())
+        except Exception as exc:
+            self.console.print(f"[error]Failed to parse {artifacts_path}: {exc}[/error]")
+            return
+
+        metrics = payload.get("_metrics")
+        if not metrics:
+            self.console.print(
+                "[warning]Metrics summary missing. Regenerate the file with [/warning]"
+                "[bold]python3 scripts/run_beta_showcase.py[/bold]."
+            )
+            return
+
+        table = Table(title="📊 Beta Harness Summary", box=box.ROUNDED)
+        table.add_column("Metric", style="bold green")
+        table.add_column("Value", style="white")
+        table.add_row("Scenarios", str(metrics.get("scenario_count", "-")))
+        elapsed = metrics.get("total_elapsed", 0.0)
+        table.add_row("Total elapsed", f"{elapsed:.2f}s")
+        guard = metrics.get("guardrail_pass_rate", 0.0)
+        table.add_row("Guardrail pass rate", f"{guard:.1%}")
+
+        tool_usage = metrics.get("tool_usage", {})
+        if tool_usage:
+            usage_lines = [f"{tool}: {count}" for tool, count in tool_usage.items()]
+            table.add_row("Tool invocations", "\n".join(usage_lines))
+
+        self.console.print(table)
+
+        guardrail_findings = []
+        for name, scenario in payload.items():
+            if not isinstance(scenario, dict) or name.startswith("_"):
+                continue
+            quality = scenario.get("quality_checks")
+            if not quality:
+                continue
+            if not all(quality.values()):
+                guardrail_findings.append((name, quality))
+
+        if guardrail_findings:
+            warn_table = Table(title="⚠️ Guardrails needing attention", box=box.ROUNDED, style="yellow")
+            warn_table.add_column("Scenario", style="bold")
+            warn_table.add_column("Checks", style="white")
+            for scenario, checks in guardrail_findings:
+                failed = [f"{key}={val}" for key, val in checks.items()]
+                warn_table.add_row(scenario, ", ".join(failed))
+            self.console.print(warn_table)
+        else:
+            self.console.print("[success]All guardrails passed.[/success]")
+
+    def show_token_report(self) -> None:
+        try:
+            from scripts.token_report import build_token_report
+        except Exception as exc:  # pragma: no cover - import convenience
+            self.console.print(f"[error]Failed to import token report tool: {exc}[/error]")
+            return
+
+        root = Path(os.getenv("NOCTURNAL_HOME", str(Path.home() / ".nocturnal_archive")))
+        report = build_token_report(root)
+        table = Table(title="🪙 Token Usage", box=box.ROUNDED)
+        table.add_column("User (hashed)", style="cyan")
+        table.add_column("Tokens", style="white", justify="right")
+        for user, tokens in report["per_user"].items():
+            table.add_row(user, f"{tokens:.0f}")
+        self.console.print(table)
+        self.console.print(f"[dim]Total tokens: {report['total_tokens']:.0f}[/dim]")
     
     def _enforce_latest_build(self):
         """Ensure the CLI is running the most recent published build."""
@@ -256,6 +379,19 @@ class NocturnalCLI:
         if not await self.initialize():
             return
         
+        # Detect if user is in a project directory (R, Python, Node, Jupyter, etc.)
+        try:
+            from .project_detector import ProjectDetector
+            detector = ProjectDetector()
+            project_info = detector.detect_project()
+            
+            if project_info:
+                # Show project banner
+                banner = detector.format_project_banner(project_info)
+                self.console.print(banner, style="dim")
+        except:
+            pass  # Silently skip if detection fails
+        
         self.console.print("\n[bold]🤖 Interactive Mode[/] — Type your questions or 'quit' to exit")
         self.console.rule(style="magenta")
         
@@ -296,18 +432,36 @@ class NocturnalCLI:
                 try:
                     from rich.spinner import Spinner
                     from rich.live import Live
-                    
-                    # Show loading indicator while processing
-                    with Live(Spinner("dots", text="[dim]Thinking...[/dim]"), console=self.console, transient=True):
+
+                    # Show detailed progress indicator
+                    spinner = Spinner("dots", text="[dim]Processing query...[/dim]")
+                    live = Live(spinner, console=self.console, transient=True)
+                    live.start()
+
+                    try:
                         request = ChatRequest(
                             question=user_input,
                             user_id="cli_user",
                             conversation_id=self.session_id
                         )
-                        
-                        response = await self.agent.process_request(request)
 
-                    # Print response with proper formatting
+                        # Update spinner based on query type
+                        if any(kw in user_input.lower() for kw in ['read', 'show', 'file', 'cat']):
+                            spinner.update(text="[cyan]📄 Reading file...[/cyan]")
+                        elif any(kw in user_input.lower() for kw in ['list', 'ls', 'find', 'search']):
+                            spinner.update(text="[cyan]🔍 Searching files...[/cyan]")
+                        elif any(kw in user_input.lower() for kw in ['python', 'calculate', 'run', 'execute']):
+                            spinner.update(text="[cyan]⚙️  Executing code...[/cyan]")
+                        elif any(kw in user_input.lower() for kw in ['research', 'paper', 'find', 'archive']):
+                            spinner.update(text="[cyan]🔬 Searching research database...[/cyan]")
+                        else:
+                            spinner.update(text="[cyan]🤖 Thinking...[/cyan]")
+
+                        response = await self.agent.process_request(request)
+                    finally:
+                        live.stop()
+
+                    # Print response immediately (no artificial typing delay)
                     self.console.print("[bold violet]🤖 Agent[/]: ", end="", highlight=False)
                     self.console.print(response.response)
 
@@ -322,12 +476,10 @@ class NocturnalCLI:
                         }
                     )
 
-                    # Show usage stats occasionally
-                    if hasattr(self.agent, 'daily_token_usage') and self.agent.daily_token_usage > 0:
-                        stats = self.agent.get_usage_stats()
-                        if stats['usage_percentage'] > 10:  # Show if >10% used
-                            self.console.print(f"\n📊 Usage: {stats['usage_percentage']:.1f}% of daily limit")
-                
+                except KeyboardInterrupt:
+                    live.stop()
+                    self.console.print("\n[dim]⏹️  Interrupted. Ask another question when ready.[/dim]")
+                    continue
                 except Exception as e:
                     self.console.print(f"\n[error]❌ Error: {e}[/error]")
         
@@ -712,6 +864,24 @@ Examples:
         action='store_true',
         help='Show recent query history'
     )
+
+    parser.add_argument(
+        '--presets',
+        action='store_true',
+        help='Show curated beta showcase prompts'
+    )
+
+    parser.add_argument(
+        '--metrics',
+        action='store_true',
+        help='Display the latest autonomy harness metrics summary'
+    )
+
+    parser.add_argument(
+        '--token-report',
+        action='store_true',
+        help='Print aggregated token usage from telemetry logs'
+    )
     
     parser.add_argument(
         '--search-library',
@@ -742,7 +912,13 @@ Examples:
         metavar='TAG',
         help='Filter library by tag'
     )
-    
+
+    parser.add_argument(
+        '--doctor',
+        action='store_true',
+        help='Run health check diagnostics'
+    )
+
     args = parser.parse_args()
     
     # Handle version
@@ -752,6 +928,28 @@ Examples:
         print("AI Research Assistant with real data integration")
         return
 
+    if args.presets:
+        cli = NocturnalCLI()
+        cli.show_presets()
+        return
+
+    # Handle doctor
+    if args.doctor:
+        import asyncio
+        from cite_agent.doctor import run_doctor
+        exit_code = asyncio.run(run_doctor())
+        sys.exit(exit_code)
+
+    if args.metrics:
+        cli = NocturnalCLI()
+        cli.show_metrics()
+        return
+
+    if args.token_report:
+        cli = NocturnalCLI()
+        cli.show_token_report()
+        return
+
     if args.tips or (args.query and args.query.lower() == "tips" and not args.interactive):
         cli = NocturnalCLI()
         cli.show_tips()
